
# Slot: skip_node_types_if_unavailable


Whether to skip the node types without raising an error if these are unavailable.

URI: [https://w3id.org/neat/ensmallenRunConfig__skip_node_types_if_unavailable](https://w3id.org/neat/ensmallenRunConfig__skip_node_types_if_unavailable)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
